%sgu_tot_run_baaff.m estimates country-by-country  SVARs for the vector x_t = [tot_t spread_t  tb_t gdp_t c_t i_t rer_t] with an intercept. Omitting the intercept, the program delivers the matrices hx and PI in  x_t = hx x_{t-1} + PI eps_t, where eps_t~(0,I).  It also computes the share of the variances of these 6 variables explained by tot shocks. 
%(c) Stephanie Schmitt-Grohe and Martn Uribe, December 2014

clear all

%Baseline case: Quadratic Detrending
load detrend_data.mat  DD country_name   ndate ntot ntb ngdp nc ni nrer nbaaff
%produced by running  detrend_data.m in directory Z:\uribe\tot\IER\mfiles and
%setting method = 'time'

%HP Filtering: 
%load detrend_data_HP.mat  DD country_name   ndate ntot ntb ngdp nc ni nrer
%produced with detrend_data.m in directory Z:\uribe\tot\IER\mfiles and
%setting method = 'HP'

ncou = length(DD);
nv = size(DD{1},2)-1; %eliminated  column is the year 
v_share = zeros(ncou,nv);


var_svar_tot = zeros(nv,ncou);
var_svar = zeros(nv,ncou); %Total population variance implies by SVAR model 
sigx = zeros(nv,nv,ncou); %
ssigx = zeros(nv,nv,ncou); %

R2 = zeros(nv,ncou);
U = cell(0);
%Restrictions on B
R = ones(nv);
R(1,3:end) = 0;
R(2,3:end) = 0;
y0 = zeros(ncou,nv);
T = 11; %length of impulse responses;

for k=1:ncou
%construct current and lagged data for country k
d = DD{k}(:,[ntot nbaaff ntb ngdp nc ni nrer]);
y0(k,:) = d(1,:);
 [hx(:,:,k),PI(:,:,k),R2(:,k),A(:,:,k),B(:,:,k),stdu(:,k),U{k}] = svar_estim(d,R,0);
%estimates by OLS the system 
%x_t = Bx_t-1 + Ax_t + u_t, and set PI = (I-A)\B and PI= (I-A)\diag(stdu) (note: by construction, the var-cov of u_t is diagonal), to get x_t = hx x_t-1 +PIe_t, where u_t = PI e_t

[~,vdx]=variance_decomposition(eye(nv),hx(:,:,k),PI(:,:,k));
v_share(k,:) = vdx(1,:)*100;

%%%%%%%%%%%%%%%%%%%%%%%%%

%Population variance
[~,sigx(:,:,k)]=mom(eye(nv),hx(:,:,k),PI(:,:,k)*PI(:,:,k)');
var_svar(:,k) = diag(sigx(:,:,k)); %total variances  implied by empirical SVAR model


%Population variance under tot shocks only
PI1 = PI(:,:,k);
PI1(:,2:end) = 0;
[~,ssigx(:,:,k)]=mom(eye(nv),hx(:,:,k),PI1*PI1');
var_svar_tot(:,k) = diag(ssigx(:,:,k)); %variances conditional on ttot shocks implied by empirical SVAR model

%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Impulse Responses
%to unit tot shock
x0 = PI(:,1,k)/PI(1,1,k);
x =ir(eye(nv),hx(:,:,k),x0,T);
IR(:,:,k) = x(:,1:nv);


%to unit tot shock
%to unit spread shock
x0 = PI(:,2,k)/PI(2,2,k);
x =ir(eye(nv),hx(:,:,k),x0,T);
IRs(:,:,k) = x(:,1:nv);

end

readme = 'The order in the SVAR is tot baaff tb gdp c i rer'

save sgu_tot_run_baaff.mat U PI hx R y0 v_share IR IRs country_name ncou R2 ntot nbaaff ntb ngdp nc ni nrer var_svar_tot var_svar
%save sgu_tot_run_baaff_HP.mat U PI hx y0 v_share IR country_name R2